publisher

# XMLRésuméLibrary: User Guide

pubDate | Element Reference | pubs

## Name

publisher — Information about a publisher of a work

## Synopsis

### Content Model

    (#PCDATA|link|url)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

The use of the `url` element as a child of `publisher` is deprecated as of XML Résumé Library version 1.4.0.

We recommend that you convert all `url`s contained in `publisher`s to `link`s.

The `publisher` element contains the name, and possibly location, of the organization that published a literary, artistic, scholary, or other work.

### Parents

`publisher` may be contained in these elements: `pub`

## Examples

Example 6. Publisher name only

    <pub>
      <bookTitle>Deep Thoughts on Stuff</bookTitle>
      <publisher>Totally Groovy Publishing, Ltd.</publisher>
    </pub>

Example 7. Publisher name and location

    <pub>
      <bookTitle>A User's Guide to Dirt</bookTitle>
      <publisher>Mother Nature Books, Boston, Massachusetts</publisher>
    </pub>

pubDate | Element Reference | pubs